@@ -1,10 +1,10 @@
 #!/usr/bin/perl
 #
 # modsec-clamscan.pl
-# mod_security, http://www.modsecurity.org
-# Copyright (c) 2002-2004 Ivan Ristic <ivanr@webkreator.com>
+# ModSecurity for Apache (http://www.modsecurity.org)
+# Copyright (c) 2002-2005 Thinking Stone (http://www.thinkingstone.com)
 #
-# $Id: modsec-clamscan.pl,v 1.1 2004/11/18 21:01:01 ivanr Exp $
+# $Id: modsec-clamscan.pl,v 1.1.2.1 2005/12/19 20:39:51 ivanr Exp $
 #
 # This script is an interface between mod_security and its
 # ability to intercept files being uploaded through the
@@ -36,7 +36,7 @@ $error_message = $1;
 
 $output = "0 Unable to parse clamscan output [$1]";
 
-if ($error_message =~ m/: Empty file\.$/) {
+if ($error_message =~ m/: Empty file\.?$/) {
     $output = "1 empty file";
 }
 elsif ($error_message =~ m/: (.+) ERROR$/) {
